==> okteta-0.25.4.tar.xz: okteta-0.25.4/kasten/controllers/view/poddecoder/abstracttypecodec.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTTYPECODEC_H
#define ABSTRACTTYPECODEC_H

// Qt
#include <QString>
#include <QVariant>

class QByteArray;

namespace Okteta {
class PODData;

class AbstractTypeCodec
{
protected:
    explicit AbstractTypeCodec(const QString& name);
    AbstractTypeCodec() = delete;

public:
    virtual ~AbstractTypeCodec();

public: // API to be implemented
    virtual QVariant value(const PODData& data, int* byteCount) const = 0;
    virtual QByteArray valueToBytes(const QVariant& value) const = 0;

    virtual bool areEqual(const QVariant& value, QVariant& otherValue) const = 0;

public:
    const QString& name() const;

private:
    QString mName;
};

inline AbstractTypeCodec::AbstractTypeCodec(const QString& name) : mName(name) {}
inline AbstractTypeCodec::~AbstractTypeCodec() = default;

inline const QString& AbstractTypeCodec::name() const { return mName; }

}

#endif

==> okteta-4.10.97.tar.xz: okteta-4.10.97/kasten/controllers/view/poddecoder/abstracttypecodec.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTTYPECODEC_H
#define ABSTRACTTYPECODEC_H

// Qt
#include <QtCore/QString>

class QByteArray;
class QVariant;


namespace Okteta
{
class PODData;


class AbstractTypeCodec
{
  protected:
    explicit AbstractTypeCodec( const QString& name );

  public:
    virtual ~AbstractTypeCodec();

  public: // API to be implemented
    virtual QVariant value( const PODData& data, int* byteCount ) const = 0;
    virtual QByteArray valueToBytes( const QVariant& value ) const = 0;

    virtual bool areEqual( const QVariant& value, QVariant& otherValue ) const = 0;

  public:
    const QString& name() const;

  private:
    QString mName;
};


inline AbstractTypeCodec::AbstractTypeCodec( const QString& name ) : mName( name ) {}
inline AbstractTypeCodec::~AbstractTypeCodec() {}

inline const QString& AbstractTypeCodec::name() const { return mName; }

}

#endif
